// -------------------------------------------------------------------------------------------------
// Modul:     DEBUG
// Funkce:    Odeslani retezce formou UART ramce na GPIO 
// Pozadavky: 1 GPIO
// -------------------------------------------------------------------------------------------------


// pin pro generovani vystupniho signalu (musi byt nastaven jako vystupni)
#define DEBUGLINE_UP        PORTB |= (1<<PB6)
#define DEBUGLINE_DOWN      PORTB &= ~(1<<PB6)
#define DEBUGLINE_IOSET     DDRB |= (1<<PB6)

// casova smycka (8MHz CPU, UART speed 38400bps@8MHz)
#define DEBUGLINE_COUNTER   23

// prototypy funkci
void debugSendChar(unsigned char arg);
void debugSendString(char *sss, unsigned char zdroj);
void debugInit(void);



// -------------------------------------------------------------------------------------------------
// Posle znak na ladici pin
// Vstup:  arg - znak pro poslani
// Vystup: nic
// -------------------------------------------------------------------------------------------------
void debugSendChar(unsigned char arg){
  unsigned int counter, x;
  unsigned char n = 11;
  x = 0x7E00 | arg<<1;
  while(n--) {
    if ((x & 1)) DEBUGLINE_UP; else DEBUGLINE_DOWN;
    counter = DEBUGLINE_COUNTER;
    while(counter--) asm("nop");
    x = x >> 1;
  }
}
// -------------------------------------------------------------------------------------------------



// -------------------------------------------------------------------------------------------------
// Posle retezen na debug UART
// Vstup:  sss            - ukazatel na retezec
//         zdroj          - typ pameti retezce FLASH nebo MEMORY
//         pdp            - pocet dodatecnych uprav retezce, pocet nize uvedenych dvojic
//         [index znak]   - index - pozice v retezci
//                        - znak - ten se pouzije misto puvodniho znaku retezce
// Vystup: nic
// -------------------------------------------------------------------------------------------------
void debugSendString(char *sss, unsigned char zdroj){
  char k;       
  if(zdroj) {
    while ((k=(*sss++))>0) debugSendChar(k);
  } else {
    while ((k=pgm_read_byte(sss++))>0) debugSendChar(k);
  }
} 
// ------------------------------------------------------------------------------------------------- 



// -------------------------------------------------------------------------------------------------
// Nastaveni debugline
// -------------------------------------------------------------------------------------------------
void debugInit(void) {
  // Nastaveni portu na debugline
  DEBUGLINE_IOSET;
}
// -------------------------------------------------------------------------------------------------
